@@ -20,24 +20,31 @@
 ### Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 ### MA 02110-1301, USA
 
-
 updateList <- function(x, val) {
-  if (is.null(x))
+  if (is.null(x)) {
     x <- list()
-  if (!is.list(val))
+  }
+  if (!is.list(val)) {
     tryCatch(val <- as.list(val))
+  }
   modifyList(x, val)
 }
 
-scale.limits <- function(x) {
-  if (is.factor(x))
+scale_limits <- function(x) {
+  if (is.factor(x)) {
     levels(x)
-  else if (is.numeric(x))
+  } else if (is.numeric(x)) {
     range(x, finite = TRUE)
-  else range(x, na.rm = TRUE)
+  } else {
+    range(x, na.rm = TRUE)
+  }
 }
 
-prepanel.null <- function () {
-  list(xlim = rep(NA_real_, 2), ylim = rep(NA_real_, 2), dx = NA_real_,
-       dy = NA_real_)
+prepanel.null <- function() {
+  list(
+    xlim = rep(NA_real_, 2),
+    ylim = rep(NA_real_, 2),
+    dx = NA_real_,
+    dy = NA_real_
+  )
 }
